#
# Conditional build:
%bcond_without	apidocs		# doxygen API documentation
%bcond_without	static_libs	# static library
%bcond_without	tests		# "make check"
#
%define		libver	43
#
Summary:	Library for high-performing platform-independent programs
Summary(pl.UTF-8):	Biblioteka do wydajnych programów niezależnych od platformy
Name:		libfilezilla
Version:	0.47.0
Release:	1
License:	GPL v2+
Group:		Libraries
Source0:	https://download.filezilla-project.org/libfilezilla/%{name}-%{version}.tar.xz
# Source0-md5:	b8fcecd37d95c903410f016ef3edb0e2
URL:		https://lib.filezilla-project.org/
BuildRequires:	autoconf >= 2.50
BuildRequires:	automake
%{?with_tests:BuildRequires:	cppunit-devel >= 1.13.0}
%{?with_apidocs:BuildRequires:	doxygen}
BuildRequires:	gettext-tools >= 0.11.0
%if %{with tests} && %(locale -a | grep -q '^C\.utf8$'; echo $?)
BuildRequires:	glibc-localedb-all
%endif
BuildRequires:	gmp-devel
BuildRequires:	gnutls-devel >= 3.7.0
# -std=c++17
BuildRequires:	libstdc++-devel >= 6:7
BuildRequires:	libtool >= 2:2
BuildRequires:	nettle-devel >= 3.3
BuildRequires:	pkgconfig >= 1:0.7
BuildRequires:	rpmbuild(macros) >= 1.583
Requires:	gnutls-libs >= 3.7.0
Requires:	nettle >= 3.3
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
libfilezilla is a free, open source C++ library, offering some basic
functionality to build high-performing, platform-independent programs.
Some of the highlights include:

- A typesafe, multi-threaded event system that's very simple to use
  yet extremely efficient
- Timers for periodic events
- A datetime class that not only tracks timestamp but also their
  accuracy, which simplifies dealing with timestamps originating from
  different sources
- Simple process handling for spawning child processes with redirected
  I/O

%description -l pl.UTF-8
libfilezilla to wolnodostępna biblioteka C++ o otwartych źródłach,
oferująca pewną podstawową funkcjonalność do tworzenia wydajnych
programów niezależnych od platformy. Uwzględnione funkcje obejmują:
- bezpieczny pod względem typów, wielowątkowy system zdarzeń - bardzo
  prosty w użyciu, a jednocześnie bardzo wydajny
- zegary do zdarzeń regularnych
- klasa daty i czasu nie tylko śledząca znacznik czasu, ale także jego
  dokładność, co upraszcza obsługę znaczników czasu pochodzących z
  różnych źródeł
- prostą obsługę procesów do tworzenia procesów potomnych z
  przekierowanym wejściem/wyjściem

%package devel
Summary:	Header files for libfilezilla library
Summary(pl.UTF-8):	Pliki nagłówkowe biblioteki libfilezilla
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}
Requires:	gnutls-devel >= 3.7.0
Requires:	libstdc++-devel >= 6:7
Requires:	nettle-devel >= 3.3

%description devel
Header files for libfilezilla library.

%description devel -l pl.UTF-8
Pliki nagłówkowe biblioteki libfilezilla.

%package static
Summary:	Static libfilezilla library
Summary(pl.UTF-8):	Statyczna biblioteka libfilezilla
Group:		Development/Libraries
Requires:	%{name}-devel = %{version}-%{release}

%description static
Static libfilezilla library.

%description static -l pl.UTF-8
Statyczna biblioteka libfilezilla.

%package apidocs
Summary:	%{name} API documentation
Summary(pl.UTF-8):	Dokumentacja API biblioteki %{name}
Group:		Documentation

%description apidocs
API documentation for %{name} library.

%description apidocs -l pl.UTF-8
Dokumentacja API biblioteki %{name}.

%prep
%setup -q

cd locales
%{__mv} bg{_BG,}.po
%{__mv} ca{_ES,}@valencia.po
%{__mv} cs{_CZ,}.po
%{__mv} fa{_IR,}.po
%{__mv} fi{_FI,}.po
%{__mv} gl{_ES,}.po
%{__mv} he{_IL,}.po
%{__mv} hu{_HU,}.po
%{__mv} id{_ID,}.po
%{__mv} ja{_JP,}.po
%{__mv} ko{_KR,}.po
%{__mv} lo{_LA,}.po
%{__mv} lt{_LT,}.po
%{__mv} lv{_LV,}.po
%{__mv} mk{_MK,}.po
%{__mv} nb{_NO,}.po
%{__mv} nn{_NO,}.po
%{__mv} pl{_PL,}.po
%{__mv} pt{_PT,}.po
%{__mv} ro{_RO,}.po
%{__mv} sk{_SK,}.po
%{__mv} sl{_SI,}.po
%{__mv} th{_TH,}.po
%{__mv} uk{_UA,}.po
%{__mv} vi{_VN,}.po

%build
%{__libtoolize}
%{__aclocal} -I m4
%{__autoconf}
%{__autoheader}
%{__automake}
%configure \
	%{!?with_static_libs:--disable-static}
%{__make}

%if %{with tests}
# wide char conversion test fails with plain C locale
LC_ALL=C.UTF-8 \
%{__make} check
%endif

%if %{with apidocs}
%{__make} -C doc html
%endif

%install
rm -rf $RPM_BUILD_ROOT

%{__make} install \
	DESTDIR=$RPM_BUILD_ROOT

%{__rm} $RPM_BUILD_ROOT%{_libdir}/*.la

# not supported by glibc (as of 2.25)
%{__rm} -r $RPM_BUILD_ROOT%{_localedir}/co

%find_lang %{name}

%clean
rm -rf $RPM_BUILD_ROOT

%post	-p /sbin/ldconfig
%postun	-p /sbin/ldconfig

%files -f %{name}.lang
%defattr(644,root,root,755)
%doc AUTHORS ChangeLog NEWS README
%attr(755,root,root) %{_libdir}/libfilezilla.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/libfilezilla.so.%{libver}

%files devel
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libfilezilla.so
%{_includedir}/libfilezilla
%{_pkgconfigdir}/libfilezilla.pc

%if %{with static_libs}
%files static
%defattr(644,root,root,755)
%{_libdir}/libfilezilla.a
%endif

%if %{with apidocs}
%files apidocs
%defattr(644,root,root,755)
%doc doc/doxygen-doc/html/*
%endif
%changelog
* Wed Apr 17 2024 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/libfilezilla.git;a=log;h=master

* Wed Apr 17 2024 Krzysztof Mrozowicz <mrozowik@pld-linux.org> c2c04a7
- up to 0.47.0

* Mon Feb 12 2024 Krzysztof Mrozowicz <mrozowik@pld-linux.org> 0c6119f
- up to 0.46.0

* Thu Oct 26 2023 Krzysztof Mrozowicz <mrozowik@pld-linux.org> 3da0394
- up to 0.45.0

* Tue Jul 11 2023 Krzysztof Mrozowicz <mrozowik@pld-linux.org> cca5b05
- up to 0.44.0

* Thu Apr 27 2023 Krzysztof Mrozowicz <mrozowik@pld-linux.org> 87527c9
- up to 0.42.2

* Thu Feb 23 2023 Krzysztof Mrozowicz <mrozowik@pld-linux.org> b2f625a
- up to 0.41.1

* Wed Feb 01 2023 Arkadiusz Miśkiewicz <arekm@maven.pl> 891a550
- Release 2 (by relup.sh)

* Tue Jan 31 2023 Krzysztof Mrozowicz <mrozowik@pld-linux.org> b592472
- up to 0.41.0

* Fri Oct 28 2022 Krzysztof Mrozowicz <mrozowik@pld-linux.org> ebe6002
- up to 0.39.2

* Mon Sep 19 2022 Krzysztof Mrozowicz <mrozowik@pld-linux.org> f542913
- up to 0.39.1

* Sun Jul 24 2022 Krzysztof Mrozowicz <mrozowik@pld-linux.org> 27b46d6
- up to 0.38.1

* Sat May 28 2022 Krzysztof Mrozowicz <mrozowik@pld-linux.org> c2f4ada
- up to 0.37.2

* Sun Apr 10 2022 Krzysztof Mrozowicz <mrozowik@pld-linux.org> ff2110f
- up to 0.37.1

* Tue Feb 15 2022 Krzysztof Mrozowicz <mrozowik@pld-linux.org> 5673b3f
- up to 0.36.0

* Sun Dec 12 2021 Krzysztof Mrozowicz <mrozowik@pld-linux.org> bf05e04
- up to 0.35.0

* Wed Oct 27 2021 Jakub Bogusz <qboosh@pld-linux.org> 9ceb078
- updated dependencies

* Wed Oct 27 2021 Jakub Bogusz <qboosh@pld-linux.org> 5b44552
- fixed macro in soname

* Wed Oct 27 2021 Krzysztof Mrozowicz <mrozowik@pld-linux.org> 3733d61
- up to 0.34.2

* Thu Aug 12 2021 Krzysztof Mrozowicz <mrozowik@pld-linux.org> 8648e4d
- up to 0.31.1

* Sat Jul 10 2021 Krzysztof Mrozowicz <mrozowik@pld-linux.org> 61510d6
- up to 0.30.0

